# cleandoc

Python package leveraging doq, black, pylint, mypy and sphinx to automatically clean and document python code.

# Usage

cleandoc [-h] [-file FILE] [-dir DIR] [-write] [-ignore] [-noclean] [-nodoc]

optional arguments:
  -h, --help           show this help message and exit
  -file FILE, -f FILE  Python (.py) file to clean
  -dir DIR, -d DIR     Directory containing Python (.py) files to clean and/or document
  -write, -w           Flag to write changes to files in-place
  -ignore, -i          Flag to continue through warnings
  -noclean, -nc        Flag to prevent cleaning of py files
  -nodoc, -nd          Flag to prevent html doc creation

## Read The Docs:

https://htmlpreview.github.io/?https://github.com/jkrist2696/cleandoc/blob/main/docs/index.html

## Install:

pip install cleandoc

## Contributing

Message me on Github.

## License

[GNU GPLv3]
(https://choosealicense.com/licenses/gpl-3.0/)

## Copyright:

(c) 2023, Jason Krist